Package: blockTools
Type: Package
Title: Block, Assign, and Diagnose Potential Interference in Randomized
        Experiments
Version: 0.6.6
Date: 2025-01-21
Authors@R: c(person(c("Ryan", "T."), "Moore", 
                    email = "rtm@american.edu", 
                    comment = c(ORCID = "0000-0002-3916-8113"), 
                    role = c("aut", "cre")),
             person("Keith", "Schnakenberg", role = "aut"))
Description: Blocks units into experimental blocks, with one unit per treatment condition, by creating a measure of multivariate distance between all possible pairs of units. Maximum, minimum, or an allowable range of differences between units on one variable can be set. Randomly assign units to treatment conditions. Diagnose potential interference between units assigned to different treatment conditions.  Write outputs to .tex and .csv files. For more information on the methods implemented, see Moore (2012) <doi:10.1093/pan/mps025>.
License: GPL (>= 2) | file LICENSE
Encoding: UTF-8
Imports: dplyr, MASS, tibble
Suggests: nbpMatching, RItools, testthat (>= 3.0.0), xtable
Depends: R (>= 3.5.0)
Config/testthat/edition: 3
URL: https://www.ryantmoore.org/html/software.blockTools.html
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-01-21 16:37:19 UTC; rtm
Author: Ryan T. Moore [aut, cre] (<https://orcid.org/0000-0002-3916-8113>),
  Keith Schnakenberg [aut]
Maintainer: Ryan T. Moore <rtm@american.edu>
Repository: CRAN
Date/Publication: 2025-01-22 08:10:05 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-28 21:45:54 UTC; unix
Archs: blockTools.so.dSYM
