useDynLib(blockTools, .registration = TRUE)
export( block,
        assignment,
        assg2xBalance,
        createBlockIDs,
        extract_conditions,
        diagnose,
        outCSV,
        outTeX,
        seqblock,
        invertRIconfInt,
        block2seqblock
)
import(MASS)

importFrom("stats", "formula", "mahalanobis", "median", "quantile",
           "var")
importFrom("utils", "write.csv")
importFrom("tibble", "is_tibble")
importFrom("dplyr", "bind_rows")

S3method(print, block)
S3method(print, assg)
S3method(print, diagnose)
S3method(print, blockSum)

